@@ -516,7 +516,7 @@ nsIPCService::ExecAsync(const char* command,
 NS_IMETHODIMP
 nsIPCService::GetRandomTime(PRUint32 *_retval)
 {
-  if (!*_retval)
+  if (!_retval)
     return NS_ERROR_NULL_POINTER;
 
   // Current local time (microsecond resolution)
@@ -620,7 +620,12 @@ nsIPCService::NewStringChannel(nsIURI* aURI, const nsACString &aContentType,
   nsresult rv;
 
   DEBUG_LOG(("nsIPCService::NewStringChannel:\n"));
-  nsCOMPtr<nsISupports> supports;
+
+  /* not supported with Moz1.5a anymore:
+    nsCOMPtr<nsISupports> supports;
+   */
+
+  nsCOMPtr<nsIInputStream> supports;
   rv = NS_NewCharInputStream(getter_AddRefs(supports), aData);
   if (NS_FAILED(rv) || !supports) return rv;
 
